# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'settingswidget.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_SettingsWidget(object):
    def setupUi(self, SettingsWidget):
        SettingsWidget.setObjectName("SettingsWidget")
        SettingsWidget.resize(431, 513)
        self.gridLayout_4 = QtWidgets.QGridLayout(SettingsWidget)
        self.gridLayout_4.setContentsMargins(-1, 0, -1, -1)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setContentsMargins(-1, 10, -1, -1)
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.btnTabGeneral = QtWidgets.QPushButton(SettingsWidget)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/pic/generalsettings.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnTabGeneral.setIcon(icon)
        self.btnTabGeneral.setIconSize(QtCore.QSize(64, 64))
        self.btnTabGeneral.setCheckable(True)
        self.btnTabGeneral.setAutoDefault(False)
        self.btnTabGeneral.setFlat(True)
        self.btnTabGeneral.setObjectName("btnTabGeneral")
        self.horizontalLayout_2.addWidget(self.btnTabGeneral)
        self.btnTabLocalRepos = QtWidgets.QPushButton(SettingsWidget)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/pic/configlocalrepos.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnTabLocalRepos.setIcon(icon1)
        self.btnTabLocalRepos.setIconSize(QtCore.QSize(64, 64))
        self.btnTabLocalRepos.setCheckable(True)
        self.btnTabLocalRepos.setAutoDefault(False)
        self.btnTabLocalRepos.setFlat(True)
        self.btnTabLocalRepos.setObjectName("btnTabLocalRepos")
        self.horizontalLayout_2.addWidget(self.btnTabLocalRepos)
        self.btnTabRemoteRepos = QtWidgets.QPushButton(SettingsWidget)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/pic/remoterepos.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnTabRemoteRepos.setIcon(icon2)
        self.btnTabRemoteRepos.setIconSize(QtCore.QSize(64, 64))
        self.btnTabRemoteRepos.setCheckable(True)
        self.btnTabRemoteRepos.setAutoDefault(False)
        self.btnTabRemoteRepos.setFlat(True)
        self.btnTabRemoteRepos.setObjectName("btnTabRemoteRepos")
        self.horizontalLayout_2.addWidget(self.btnTabRemoteRepos)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem1)
        self.gridLayout_4.addLayout(self.horizontalLayout_2, 0, 0, 1, 1)
        self.btns = QtWidgets.QDialogButtonBox(SettingsWidget)
        self.btns.setOrientation(QtCore.Qt.Horizontal)
        self.btns.setStandardButtons(QtWidgets.QDialogButtonBox.Ok)
        self.btns.setObjectName("btns")
        self.gridLayout_4.addWidget(self.btns, 3, 0, 1, 1)
        self.tabs = QtWidgets.QStackedWidget(SettingsWidget)
        self.tabs.setObjectName("tabs")
        self.pageGeneral = QtWidgets.QWidget()
        self.pageGeneral.setObjectName("pageGeneral")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.pageGeneral)
        self.gridLayout_5.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.wGeneral = QtWidgets.QGroupBox(self.pageGeneral)
        self.wGeneral.setObjectName("wGeneral")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.wGeneral)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label = QtWidgets.QLabel(self.wGeneral)
        self.label.setObjectName("label")
        self.gridLayout_2.addWidget(self.label, 0, 0, 1, 1)
        self.chkHideStartupWindow = QtWidgets.QCheckBox(self.wGeneral)
        self.chkHideStartupWindow.setObjectName("chkHideStartupWindow")
        self.gridLayout_2.addWidget(self.chkHideStartupWindow, 1, 0, 1, 2)
        self.spnMaxRecentFiles = QtWidgets.QSpinBox(self.wGeneral)
        self.spnMaxRecentFiles.setMaximum(31)
        self.spnMaxRecentFiles.setObjectName("spnMaxRecentFiles")
        self.gridLayout_2.addWidget(self.spnMaxRecentFiles, 0, 1, 1, 1)
        self.gridLayout_5.addWidget(self.wGeneral, 0, 0, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_5.addItem(spacerItem2, 1, 0, 1, 1)
        self.tabs.addWidget(self.pageGeneral)
        self.pageLocalRepos = QtWidgets.QWidget()
        self.pageLocalRepos.setObjectName("pageLocalRepos")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.pageLocalRepos)
        self.gridLayout_7.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.groupBox_2 = QtWidgets.QGroupBox(self.pageLocalRepos)
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout.setObjectName("gridLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.btnFilterPackageAdd = QtWidgets.QPushButton(self.groupBox_2)
        self.btnFilterPackageAdd.setObjectName("btnFilterPackageAdd")
        self.horizontalLayout.addWidget(self.btnFilterPackageAdd)
        self.btnFilterPackageRemove = QtWidgets.QPushButton(self.groupBox_2)
        self.btnFilterPackageRemove.setObjectName("btnFilterPackageRemove")
        self.horizontalLayout.addWidget(self.btnFilterPackageRemove)
        self.gridLayout.addLayout(self.horizontalLayout, 1, 0, 1, 2)
        self.lstFilterPackages = QtWidgets.QTreeView(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lstFilterPackages.sizePolicy().hasHeightForWidth())
        self.lstFilterPackages.setSizePolicy(sizePolicy)
        self.lstFilterPackages.setIndentation(0)
        self.lstFilterPackages.setObjectName("lstFilterPackages")
        self.gridLayout.addWidget(self.lstFilterPackages, 0, 0, 1, 1)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.btnFilterPackageMoveUp = QtWidgets.QToolButton(self.groupBox_2)
        self.btnFilterPackageMoveUp.setObjectName("btnFilterPackageMoveUp")
        self.verticalLayout_3.addWidget(self.btnFilterPackageMoveUp)
        self.btnFilterPackageMoveDown = QtWidgets.QToolButton(self.groupBox_2)
        self.btnFilterPackageMoveDown.setObjectName("btnFilterPackageMoveDown")
        self.verticalLayout_3.addWidget(self.btnFilterPackageMoveDown)
        spacerItem3 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        self.verticalLayout_3.addItem(spacerItem3)
        self.gridLayout.addLayout(self.verticalLayout_3, 0, 1, 1, 1)
        self.gridLayout_7.addWidget(self.groupBox_2, 0, 0, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_7.addItem(spacerItem4, 1, 0, 1, 1)
        self.tabs.addWidget(self.pageLocalRepos)
        self.pageRemoteRepos = QtWidgets.QWidget()
        self.pageRemoteRepos.setObjectName("pageRemoteRepos")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.pageRemoteRepos)
        self.gridLayout_6.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.groupBox_3 = QtWidgets.QGroupBox(self.pageRemoteRepos)
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridLayout_8 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.chkRemoteAllow = QtWidgets.QCheckBox(self.groupBox_3)
        self.chkRemoteAllow.setObjectName("chkRemoteAllow")
        self.gridLayout_8.addWidget(self.chkRemoteAllow, 0, 0, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.groupBox_3)
        self.label_2.setWordWrap(True)
        self.label_2.setObjectName("label_2")
        self.gridLayout_8.addWidget(self.label_2, 1, 0, 1, 1)
        self.gridLayout_6.addWidget(self.groupBox_3, 1, 0, 1, 1)
        spacerItem5 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_6.addItem(spacerItem5, 3, 0, 1, 1)
        self.grpGithubAuth = QtWidgets.QGroupBox(self.pageRemoteRepos)
        self.grpGithubAuth.setObjectName("grpGithubAuth")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.grpGithubAuth)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.chkGithubAuth = QtWidgets.QCheckBox(self.grpGithubAuth)
        self.chkGithubAuth.setObjectName("chkGithubAuth")
        self.gridLayout_3.addWidget(self.chkGithubAuth, 0, 0, 1, 2)
        self.lblGithubAuthStatus = QtWidgets.QLabel(self.grpGithubAuth)
        self.lblGithubAuthStatus.setTextFormat(QtCore.Qt.RichText)
        self.lblGithubAuthStatus.setObjectName("lblGithubAuthStatus")
        self.gridLayout_3.addWidget(self.lblGithubAuthStatus, 1, 0, 1, 2)
        self.gridLayout_6.addWidget(self.grpGithubAuth, 2, 0, 1, 1)
        self.tabs.addWidget(self.pageRemoteRepos)
        self.gridLayout_4.addWidget(self.tabs, 1, 0, 1, 1)

        self.retranslateUi(SettingsWidget)
        self.tabs.setCurrentIndex(0)
        self.btns.accepted.connect(SettingsWidget.accept)
        self.btns.rejected.connect(SettingsWidget.reject)
        QtCore.QMetaObject.connectSlotsByName(SettingsWidget)

    def retranslateUi(self, SettingsWidget):
        _translate = QtCore.QCoreApplication.translate
        SettingsWidget.setWindowTitle(_translate("SettingsWidget", "Settings"))
        self.btnTabGeneral.setToolTip(_translate("SettingsWidget", "General settings"))
        self.btnTabLocalRepos.setToolTip(_translate("SettingsWidget", "Configure local filter packages"))
        self.btnTabRemoteRepos.setToolTip(_translate("SettingsWidget", "Remote filter packages"))
        self.wGeneral.setTitle(_translate("SettingsWidget", "General"))
        self.label.setText(_translate("SettingsWidget", "Remember recent files:"))
        self.chkHideStartupWindow.setText(_translate("SettingsWidget", "Hide startup window after opening a document"))
        self.groupBox_2.setTitle(_translate("SettingsWidget", "Configure local filter packages"))
        self.btnFilterPackageAdd.setText(_translate("SettingsWidget", "Add filter package ..."))
        self.btnFilterPackageRemove.setText(_translate("SettingsWidget", "Forget package"))
        self.btnFilterPackageMoveUp.setText(_translate("SettingsWidget", "▲"))
        self.btnFilterPackageMoveDown.setText(_translate("SettingsWidget", "▼"))
        self.groupBox_3.setTitle(_translate("SettingsWidget", "Remote filter packages"))
        self.chkRemoteAllow.setText(_translate("SettingsWidget", "Allow access to remote filter packages"))
        self.label_2.setText(_translate("SettingsWidget", "Warning: filters are python scripts that can execute arbitrary code. Only run filters from sources you trust."))
        self.grpGithubAuth.setTitle(_translate("SettingsWidget", "Github repositories as filter packages"))
        self.chkGithubAuth.setText(_translate("SettingsWidget", "Use authentication (e.g. access private repositories)"))
        self.lblGithubAuthStatus.setText(_translate("SettingsWidget", "&lt;auth status here...>"))


from . import bibolamazi_res_rc
