# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'openbibfile.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_OpenBibFile(object):
    def setupUi(self, OpenBibFile):
        OpenBibFile.setObjectName("OpenBibFile")
        OpenBibFile.resize(840, 569)
        self.lyt = QtWidgets.QGridLayout(OpenBibFile)
        self.lyt.setObjectName("lyt")
        self.btnGo = QtWidgets.QPushButton(OpenBibFile)
        self.btnGo.setMinimumSize(QtCore.QSize(0, 40))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/pic/ok.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnGo.setIcon(icon)
        self.btnGo.setObjectName("btnGo")
        self.lyt.addWidget(self.btnGo, 1, 0, 1, 1)
        self.btnInterrupt = QtWidgets.QPushButton(OpenBibFile)
        self.btnInterrupt.setMinimumSize(QtCore.QSize(0, 40))
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/pic/closehide.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnInterrupt.setIcon(icon1)
        self.btnInterrupt.setObjectName("btnInterrupt")
        self.lyt.addWidget(self.btnInterrupt, 2, 0, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.btnPageEditConfig = QtWidgets.QPushButton(OpenBibFile)
        self.btnPageEditConfig.setCheckable(True)
        self.btnPageEditConfig.setChecked(True)
        self.btnPageEditConfig.setFlat(True)
        self.btnPageEditConfig.setObjectName("btnPageEditConfig")
        self.horizontalLayout_2.addWidget(self.btnPageEditConfig)
        self.btnPageFileInfo = QtWidgets.QPushButton(OpenBibFile)
        self.btnPageFileInfo.setCheckable(True)
        self.btnPageFileInfo.setFlat(True)
        self.btnPageFileInfo.setObjectName("btnPageFileInfo")
        self.horizontalLayout_2.addWidget(self.btnPageFileInfo)
        self.btnPageRunMessages = QtWidgets.QPushButton(OpenBibFile)
        self.btnPageRunMessages.setCheckable(True)
        self.btnPageRunMessages.setFlat(True)
        self.btnPageRunMessages.setObjectName("btnPageRunMessages")
        self.horizontalLayout_2.addWidget(self.btnPageRunMessages)
        self.lyt.addLayout(self.horizontalLayout_2, 5, 0, 1, 1)
        self.wHead = QtWidgets.QWidget(OpenBibFile)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.wHead.sizePolicy().hasHeightForWidth())
        self.wHead.setSizePolicy(sizePolicy)
        self.wHead.setObjectName("wHead")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.wHead)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setSpacing(3)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.lblFileName = QtWidgets.QLabel(self.wHead)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lblFileName.sizePolicy().hasHeightForWidth())
        self.lblFileName.setSizePolicy(sizePolicy)
        self.lblFileName.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.lblFileName.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.lblFileName.setMidLineWidth(1)
        self.lblFileName.setTextFormat(QtCore.Qt.PlainText)
        self.lblFileName.setAlignment(QtCore.Qt.AlignCenter)
        self.lblFileName.setObjectName("lblFileName")
        self.horizontalLayout.addWidget(self.lblFileName)
        self.btnRefresh = QtWidgets.QToolButton(self.wHead)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/pic/refresh.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnRefresh.setIcon(icon2)
        self.btnRefresh.setIconSize(QtCore.QSize(22, 22))
        self.btnRefresh.setObjectName("btnRefresh")
        self.horizontalLayout.addWidget(self.btnRefresh)
        self.btnSave = QtWidgets.QToolButton(self.wHead)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/pic/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnSave.setIcon(icon3)
        self.btnSave.setIconSize(QtCore.QSize(22, 22))
        self.btnSave.setObjectName("btnSave")
        self.horizontalLayout.addWidget(self.btnSave)
        self.lyt.addWidget(self.wHead, 0, 0, 1, 1)
        self.tabs = QtWidgets.QStackedWidget(OpenBibFile)
        self.tabs.setObjectName("tabs")
        self.tabPageEditFilters = QtWidgets.QWidget()
        self.tabPageEditFilters.setObjectName("tabPageEditFilters")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.tabPageEditFilters)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 8)
        self.verticalLayout_2.setSpacing(3)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.splitEditConfig = QtWidgets.QSplitter(self.tabPageEditFilters)
        self.splitEditConfig.setOrientation(QtCore.Qt.Horizontal)
        self.splitEditConfig.setObjectName("splitEditConfig")
        self.pageConfigEditWidget = QtWidgets.QWidget(self.splitEditConfig)
        self.pageConfigEditWidget.setObjectName("pageConfigEditWidget")
        self.pageConfigEdit = QtWidgets.QVBoxLayout(self.pageConfigEditWidget)
        self.pageConfigEdit.setContentsMargins(0, 0, 0, 0)
        self.pageConfigEdit.setObjectName("pageConfigEdit")
        self.searchConfigWidget = SearchWidget(self.pageConfigEditWidget)
        self.searchConfigWidget.setObjectName("searchConfigWidget")
        self.pageConfigEdit.addWidget(self.searchConfigWidget)
        self.txtConfig = QtWidgets.QTextEdit(self.pageConfigEditWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtConfig.sizePolicy().hasHeightForWidth())
        self.txtConfig.setSizePolicy(sizePolicy)
        self.txtConfig.setAcceptRichText(False)
        self.txtConfig.setObjectName("txtConfig")
        self.pageConfigEdit.addWidget(self.txtConfig)
        self.stackEditTools = QtWidgets.QStackedWidget(self.splitEditConfig)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.stackEditTools.sizePolicy().hasHeightForWidth())
        self.stackEditTools.setSizePolicy(sizePolicy)
        self.stackEditTools.setObjectName("stackEditTools")
        self.toolspageBase = QtWidgets.QWidget()
        self.toolspageBase.setObjectName("toolspageBase")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.toolspageBase)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.lblFavorites = QtWidgets.QLabel(self.toolspageBase)
        self.lblFavorites.setTextFormat(QtCore.Qt.RichText)
        self.lblFavorites.setAlignment(QtCore.Qt.AlignCenter)
        self.lblFavorites.setTextInteractionFlags(QtCore.Qt.NoTextInteraction)
        self.lblFavorites.setObjectName("lblFavorites")
        self.verticalLayout_3.addWidget(self.lblFavorites)
        self.treeFavorites = QtWidgets.QTreeView(self.toolspageBase)
        self.treeFavorites.setDragDropMode(QtWidgets.QAbstractItemView.InternalMove)
        self.treeFavorites.setRootIsDecorated(False)
        self.treeFavorites.setObjectName("treeFavorites")
        self.treeFavorites.header().setVisible(False)
        self.verticalLayout_3.addWidget(self.treeFavorites)
        self.line = QtWidgets.QFrame(self.toolspageBase)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.verticalLayout_3.addWidget(self.line)
        self.btnAddSourceList = QtWidgets.QPushButton(self.toolspageBase)
        self.btnAddSourceList.setObjectName("btnAddSourceList")
        self.verticalLayout_3.addWidget(self.btnAddSourceList)
        self.btnAddFilter = QtWidgets.QPushButton(self.toolspageBase)
        self.btnAddFilter.setObjectName("btnAddFilter")
        self.verticalLayout_3.addWidget(self.btnAddFilter)
        self.stackEditTools.addWidget(self.toolspageBase)
        self.toolspageSource = QtWidgets.QWidget()
        self.toolspageSource.setObjectName("toolspageSource")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.toolspageSource)
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.sourceListEditor = SourceListEditor(self.toolspageSource)
        self.sourceListEditor.setObjectName("sourceListEditor")
        self.verticalLayout_4.addWidget(self.sourceListEditor)
        self.stackEditTools.addWidget(self.toolspageSource)
        self.toolspageFilter = QtWidgets.QWidget()
        self.toolspageFilter.setObjectName("toolspageFilter")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.toolspageFilter)
        self.verticalLayout_5.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.filterInstanceEditor = FilterInstanceEditor(self.toolspageFilter)
        self.filterInstanceEditor.setObjectName("filterInstanceEditor")
        self.verticalLayout_5.addWidget(self.filterInstanceEditor)
        self.stackEditTools.addWidget(self.toolspageFilter)
        self.toolspagePackage = QtWidgets.QWidget()
        self.toolspagePackage.setObjectName("toolspagePackage")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.toolspagePackage)
        self.verticalLayout_6.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.filterPackagePathEditor = FilterPackagePathEditor(self.toolspagePackage)
        self.filterPackagePathEditor.setObjectName("filterPackagePathEditor")
        self.verticalLayout_6.addWidget(self.filterPackagePathEditor)
        self.stackEditTools.addWidget(self.toolspagePackage)
        self.toolspageSelectedMultiple = QtWidgets.QWidget()
        self.toolspageSelectedMultiple.setObjectName("toolspageSelectedMultiple")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.toolspageSelectedMultiple)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        spacerItem = QtWidgets.QSpacerItem(20, 123, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_7.addItem(spacerItem)
        self.lblSelectedMultiple = QtWidgets.QLabel(self.toolspageSelectedMultiple)
        self.lblSelectedMultiple.setObjectName("lblSelectedMultiple")
        self.verticalLayout_7.addWidget(self.lblSelectedMultiple)
        self.btnSelectedMultipleAddFavorite = QtWidgets.QPushButton(self.toolspageSelectedMultiple)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/pic/bookmark.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnSelectedMultipleAddFavorite.setIcon(icon4)
        self.btnSelectedMultipleAddFavorite.setObjectName("btnSelectedMultipleAddFavorite")
        self.verticalLayout_7.addWidget(self.btnSelectedMultipleAddFavorite)
        spacerItem1 = QtWidgets.QSpacerItem(20, 123, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_7.addItem(spacerItem1)
        self.stackEditTools.addWidget(self.toolspageSelectedMultiple)
        self.verticalLayout_2.addWidget(self.splitEditConfig)
        self.tabs.addWidget(self.tabPageEditFilters)
        self.tabPageFileInfo = QtWidgets.QWidget()
        self.tabPageFileInfo.setObjectName("tabPageFileInfo")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.tabPageFileInfo)
        self.gridLayout_3.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout()
        self.verticalLayout_8.setSpacing(0)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Maximum)
        self.verticalLayout_8.addItem(spacerItem2)
        self.btnInfoPageHeader = QtWidgets.QPushButton(self.tabPageFileInfo)
        self.btnInfoPageHeader.setMinimumSize(QtCore.QSize(0, 50))
        self.btnInfoPageHeader.setCheckable(True)
        self.btnInfoPageHeader.setChecked(True)
        self.btnInfoPageHeader.setFlat(True)
        self.btnInfoPageHeader.setObjectName("btnInfoPageHeader")
        self.verticalLayout_8.addWidget(self.btnInfoPageHeader)
        self.btnInfoPageEntries = QtWidgets.QPushButton(self.tabPageFileInfo)
        self.btnInfoPageEntries.setMinimumSize(QtCore.QSize(0, 50))
        self.btnInfoPageEntries.setCheckable(True)
        self.btnInfoPageEntries.setFlat(True)
        self.btnInfoPageEntries.setObjectName("btnInfoPageEntries")
        self.verticalLayout_8.addWidget(self.btnInfoPageEntries)
        spacerItem3 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_8.addItem(spacerItem3)
        self.gridLayout_3.addLayout(self.verticalLayout_8, 0, 0, 1, 1)
        self.stkInfo = QtWidgets.QStackedWidget(self.tabPageFileInfo)
        self.stkInfo.setObjectName("stkInfo")
        self.pageInfoHeader = QtWidgets.QWidget()
        self.pageInfoHeader.setObjectName("pageInfoHeader")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.pageInfoHeader)
        self.gridLayout_5.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.txtInfo = QtWidgets.QTextBrowser(self.pageInfoHeader)
        self.txtInfo.setTabChangesFocus(True)
        self.txtInfo.setOpenLinks(False)
        self.txtInfo.setObjectName("txtInfo")
        self.gridLayout_5.addWidget(self.txtInfo, 0, 0, 1, 1)
        self.stkInfo.addWidget(self.pageInfoHeader)
        self.pageInfoEntries = QtWidgets.QWidget()
        self.pageInfoEntries.setObjectName("pageInfoEntries")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.pageInfoEntries)
        self.gridLayout_4.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_4.setVerticalSpacing(5)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.searchPrevBibEntries = SearchWidget(self.pageInfoEntries)
        self.searchPrevBibEntries.setObjectName("searchPrevBibEntries")
        self.gridLayout_4.addWidget(self.searchPrevBibEntries, 0, 0, 1, 1)
        self.txtBibEntries = QtWidgets.QTextBrowser(self.pageInfoEntries)
        font = QtGui.QFont()
        font.setFamily("Courier 10 Pitch")
        self.txtBibEntries.setFont(font)
        self.txtBibEntries.setTabChangesFocus(True)
        self.txtBibEntries.setOpenLinks(False)
        self.txtBibEntries.setObjectName("txtBibEntries")
        self.gridLayout_4.addWidget(self.txtBibEntries, 1, 0, 1, 1)
        self.stkInfo.addWidget(self.pageInfoEntries)
        self.gridLayout_3.addWidget(self.stkInfo, 0, 1, 1, 1)
        self.gridLayout_3.setColumnStretch(1, 1)
        self.tabs.addWidget(self.tabPageFileInfo)
        self.tabsPage = QtWidgets.QWidget()
        self.tabsPage.setObjectName("tabsPage")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.tabsPage)
        self.verticalLayout.setContentsMargins(0, 0, 0, 8)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tabs.addWidget(self.tabsPage)
        self.pageBibEntries = QtWidgets.QWidget()
        self.pageBibEntries.setObjectName("pageBibEntries")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.pageBibEntries)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 8)
        self.gridLayout_2.setVerticalSpacing(3)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.tabs.addWidget(self.pageBibEntries)
        self.tabPageRunMessages = QtWidgets.QWidget()
        self.tabPageRunMessages.setObjectName("tabPageRunMessages")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.tabPageRunMessages)
        self.verticalLayout_9.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.txtParseErrorMessages = QtWidgets.QTextBrowser(self.tabPageRunMessages)
        self.txtParseErrorMessages.setTabChangesFocus(True)
        self.txtParseErrorMessages.setOpenLinks(False)
        self.txtParseErrorMessages.setObjectName("txtParseErrorMessages")
        self.verticalLayout_9.addWidget(self.txtParseErrorMessages)
        self.lytRunOptions = QtWidgets.QHBoxLayout()
        self.lytRunOptions.setObjectName("lytRunOptions")
        self.label = QtWidgets.QLabel(self.tabPageRunMessages)
        self.label.setObjectName("label")
        self.lytRunOptions.addWidget(self.label)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.lytRunOptions.addItem(spacerItem4)
        self.lblVerbosity = QtWidgets.QLabel(self.tabPageRunMessages)
        self.lblVerbosity.setObjectName("lblVerbosity")
        self.lytRunOptions.addWidget(self.lblVerbosity)
        self.cbxVerbosity = QtWidgets.QComboBox(self.tabPageRunMessages)
        self.cbxVerbosity.setObjectName("cbxVerbosity")
        self.cbxVerbosity.addItem("")
        self.cbxVerbosity.addItem("")
        self.cbxVerbosity.addItem("")
        self.cbxVerbosity.addItem("")
        self.lytRunOptions.addWidget(self.cbxVerbosity)
        self.line_2 = QtWidgets.QFrame(self.tabPageRunMessages)
        self.line_2.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.lytRunOptions.addWidget(self.line_2)
        self.btnDeleteCache = QtWidgets.QPushButton(self.tabPageRunMessages)
        self.btnDeleteCache.setObjectName("btnDeleteCache")
        self.lytRunOptions.addWidget(self.btnDeleteCache)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.lytRunOptions.addItem(spacerItem5)
        self.verticalLayout_9.addLayout(self.lytRunOptions)
        self.txtLog = QtWidgets.QTextBrowser(self.tabPageRunMessages)
        self.txtLog.setTabChangesFocus(True)
        self.txtLog.setHtml("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'.SF NS Text\'; font-size:13pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:\'Courier 10 Pitch\';\"><br /></p></body></html>")
        self.txtLog.setAcceptRichText(False)
        self.txtLog.setOpenLinks(False)
        self.txtLog.setObjectName("txtLog")
        self.verticalLayout_9.addWidget(self.txtLog)
        self.tabs.addWidget(self.tabPageRunMessages)
        self.lyt.addWidget(self.tabs, 6, 0, 1, 1)

        self.retranslateUi(OpenBibFile)
        self.tabs.setCurrentIndex(0)
        self.stackEditTools.setCurrentIndex(0)
        self.stkInfo.setCurrentIndex(0)
        self.cbxVerbosity.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(OpenBibFile)

    def retranslateUi(self, OpenBibFile):
        _translate = QtCore.QCoreApplication.translate
        self.btnGo.setText(_translate("OpenBibFile", "Run Bibolamazi !"))
        self.btnInterrupt.setText(_translate("OpenBibFile", "Stop"))
        self.btnPageEditConfig.setText(_translate("OpenBibFile", "Edit filters"))
        self.btnPageFileInfo.setText(_translate("OpenBibFile", "Bibolamazi file information"))
        self.btnPageRunMessages.setText(_translate("OpenBibFile", "Run messages"))
        self.lblFileName.setText(_translate("OpenBibFile", "some text here"))
        self.lblFavorites.setText(_translate("OpenBibFile", "<html><head/><body><p>Favorite commands&nbsp;&nbsp;<img src=\":/pic/bookmark.png\"></p></body></html>"))
        self.btnAddSourceList.setText(_translate("OpenBibFile", "add source list ..."))
        self.btnAddFilter.setText(_translate("OpenBibFile", "insert filter ..."))
        self.lblSelectedMultiple.setText(_translate("OpenBibFile", "Multiple commands selected"))
        self.btnSelectedMultipleAddFavorite.setText(_translate("OpenBibFile", "add them together as a favorite"))
        self.btnInfoPageHeader.setText(_translate("OpenBibFile", "show header"))
        self.btnInfoPageEntries.setText(_translate("OpenBibFile", "filtered entries"))
        self.txtInfo.setHtml(_translate("OpenBibFile", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'.SF NS Text\'; font-size:13pt; font-weight:400; font-style:normal;\">\n"
"<p align=\"center\" style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-style:italic; color:#b1311d;\">&lt;no header to show&gt;</span></p></body></html>"))
        self.txtParseErrorMessages.setHtml(_translate("OpenBibFile", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'.SF NS Text\'; font-size:13pt; font-weight:400; font-style:normal;\">\n"
"<p align=\"center\" style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-style:italic; color:#b1311d;\">&lt;no error messages&gt;</span></p></body></html>"))
        self.label.setText(_translate("OpenBibFile", "Options affect next run:"))
        self.lblVerbosity.setText(_translate("OpenBibFile", "Log verbosity:"))
        self.cbxVerbosity.setItemText(0, _translate("OpenBibFile", "Quiet"))
        self.cbxVerbosity.setItemText(1, _translate("OpenBibFile", "Information"))
        self.cbxVerbosity.setItemText(2, _translate("OpenBibFile", "Verbose"))
        self.cbxVerbosity.setItemText(3, _translate("OpenBibFile", "Very Verbose (debug)"))
        self.btnDeleteCache.setText(_translate("OpenBibFile", "Delete cache"))


from ..filterinstanceeditor import FilterInstanceEditor
from ..filterpackagepatheditor import FilterPackagePathEditor
from ..searchwidget import SearchWidget
from ..sourcelisteditor import SourceListEditor
from . import bibolamazi_res_rc
